# Description
**openfrom** is a tool that opens multiple pages from a single base URL by appending unique strings to it and opening them in separate tabs. It saves time when accessing similar URL structures on a website.
# Install
`pip install openfrom`

